/* =====================================================================================================
 * Accessory Info holds and parses the information on the accessory like description, type and geometry
 * of the display.
 * =====================================================================================================
 * By: Zakie Mashiah 
 * =====================================================================================================
 */
package myPhoneInfo.test.zakiem;

/* Input description
 * 		type=string
 * 		intensity=number
 * 		height=number
 * 		width=number
 */
public class AccessoryInfo {
	
	private byte[] buffer = new byte[64];
	private int    bufferPos;
	private static final String typeToken = "type=";
	private static final String intensityToken = "intensity=";
	private static final String heightToken = "height=";
	private static final String widthToken = "width=";

	private String accessoryType;
	private int    accessoryIntensity;
	private int	   accessoryHeight;
	private int    accessoryWidth;

	private int    dataBitMask; // Which element was read
	private static int BM_TYPE		= 0x01;
	private static int BM_INTEN 	= 0x02;
	private static int BM_HEIGHT	= 0x04;
	private static int BM_WIDTH		= 0x08;
	private boolean accessoryInfoAvailable = false; // True if we got all the information we are expecting
	
	public String getAccessoryType() { return accessoryType; }
	public int getAccessoryIntensity() { return accessoryIntensity; }
	public int getAccessoryHeight() { return accessoryHeight; }
	public int getAccessoryWidth() { return accessoryWidth; }
	public boolean isAccessoryInfoAvailable() { return accessoryInfoAvailable; }

	/** 
	 * Adds a character from the BT socket to internal buffer and process the buffer if character is \r
	 * @param b	The character from the BT socket
	 */
	public void addCharacter(byte b) {
		if (b == '\r')
			processBuffer();
		buffer[bufferPos] = b;
		bufferPos++;
		if (bufferPos >= buffer.length)
			bufferPos = 0;
	}

	/**
	 * Process the current buffer from the BT socket
	 */
	public void processBuffer() {
		String streamLine = new String();
		int valuePos;
		String valueString = null;
		int    valueInt;
		
		for(int i=0; i<bufferPos; i++)
			streamLine += (char)buffer[i];
		accessoryInfoAvailable = false;
		if (streamLine.contains(typeToken)) {
			valuePos = streamLine.indexOf('=');
			if (valuePos > 0) {
				valuePos++;
				valueString = streamLine.substring(valuePos);
				dataBitMask |= BM_TYPE;
				accessoryType = valueString;
			}
		}
		else if (streamLine.contains(intensityToken)) {
			valuePos = streamLine.indexOf('=');
			if (valuePos > 0) {
				valuePos++;
				valueString = streamLine.substring(valuePos);
				try {
					valueInt = Integer.parseInt(valueString);
					dataBitMask |= BM_INTEN;
					accessoryIntensity = valueInt;
				} catch(Exception e) {}
			}
		}
		else if (streamLine.contains(heightToken)) {
			valuePos = streamLine.indexOf('=');
			if (valuePos > 0) {
				valuePos++;
				valueString = streamLine.substring(valuePos);
				try {
					valueInt = Integer.parseInt(valueString);
					dataBitMask |= BM_HEIGHT;
					accessoryHeight = valueInt;
				} catch(Exception e) {}
			}
		}
		else if (streamLine.contains(widthToken)) {
			valuePos = streamLine.indexOf('=');
			if (valuePos > 0) {
				valuePos++;
				valueString = streamLine.substring(valuePos);
				try {
					valueInt = Integer.parseInt(valueString);
					dataBitMask |= BM_WIDTH;
					accessoryWidth = valueInt;
				} catch(Exception e) {}
			}
		}
		if (dataBitMask == 0x0F) {
			dataBitMask = 0;
			accessoryInfoAvailable = true;
			
		}
		// Clear the buffer
		bufferPos = 0;
		java.util.Arrays.fill(buffer, (byte)0);
	}
	

}
